@@ -11,12 +11,12 @@ use super::fetch::Range;
 use crate::{ipc::BootstrapConfig, Error, Result};
 use hex::encode;
 use log::{debug, info};
-use safe_network::client::{Client, Error as ClientError, ErrorMessage, TransfersError};
+use safe_network::client::{Client, Error as ClientError, ErrorMessage};
 use safe_network::types::{
     register::{Address, Entry, EntryHash, PrivatePermissions, PublicPermissions, User},
     ChunkAddress, Error as SafeNdError, Keypair, Map, MapAction, MapAddress, MapEntryActions,
-    MapPermissionSet, MapSeqEntryActions, MapSeqValue, MapValue, PublicKey, SequenceAddress,
-    SequencePrivatePermissions, SequencePublicPermissions, SequenceUser, Token,
+    MapKind, MapPermissionSet, MapValue, SequenceAddress, SequencePrivatePermissions,
+    SequencePublicPermissions, SequenceUser,
 };
 use std::{
     collections::{BTreeMap, BTreeSet, HashSet},
@@ -99,111 +99,6 @@ impl SafeAppClient {
         Ok(client.keypair())
     }
 
-    // === Token operations ===
-    pub async fn read_balance_from_keypair(&self, id: Keypair) -> Result<Token> {
-        let temp_client = Client::new(
-            Some(id),
-            self.config_path.as_deref(),
-            self.bootstrap_config.clone(),
-            self.timeout.as_secs(),
-        )
-        .await?;
-
-        temp_client
-            .get_balance()
-            .await
-            .map_err(|err| Error::NetDataError(format!("Failed to retrieve balance: {:?}", err)))
-    }
-
-    #[cfg(feature = "simulated-payouts")]
-    pub async fn trigger_simulated_farming_payout(
-        &self,
-        amount: Token,
-        id: Option<Keypair>,
-    ) -> Result<()> {
-        let mut client = if id.is_some() {
-            Client::new(
-                id,
-                self.config_path.as_deref(),
-                self.bootstrap_config.clone(),
-                self.timeout.as_secs(),
-            )
-            .await?
-        } else {
-            self.get_safe_client()?
-        };
-
-        client.trigger_simulated_farming_payout(amount).await?;
-
-        Ok(())
-    }
-
-    pub async fn safecoin_transfer_to_xorname(
-        &self,
-        from_id: Option<Keypair>,
-        to_xorname: XorName,
-        amount: Token,
-    ) -> Result<u64> {
-        // Get pk from xorname. We assume Ed25519 key for now, which is
-        // 32 bytes long, just like a xorname.
-        // TODO: support for BLS keys which are longer.
-        let to_pk = ed25519_dalek::PublicKey::from_bytes(to_xorname.as_ref()).map_err(|err| {
-            Error::NetDataError(format!(
-                "Failed to derive Ed25519 PublicKey from Xorname '{}': {:?}",
-                to_xorname, err
-            ))
-        })?;
-
-        self.safecoin_transfer_to_pk(from_id, to_pk.into(), amount)
-            .await
-    }
-
-    pub async fn safecoin_transfer_to_pk(
-        &self,
-        from_id: Option<Keypair>,
-        to_pk: PublicKey,
-        amount: Token,
-    ) -> Result<u64> {
-        let client = match from_id {
-            Some(id) => {
-                Client::new(
-                    Some(id),
-                    self.config_path.as_deref(),
-                    self.bootstrap_config.clone(),
-                    self.timeout.as_secs(),
-                )
-                .await?
-            }
-            None => self.get_safe_client()?,
-        };
-
-        let (dot_counter, _dot_actor) =
-            client
-                .send_tokens(to_pk, amount)
-                .await
-                .map_err(|err| match err {
-                    ClientError::Transfer(TransfersError::ZeroValueTransfer) => {
-                        Error::InvalidAmount("Cannot send zero-value transfers".to_string())
-                    }
-                    ClientError::Transfer(TransfersError::InsufficientBalance) => {
-                        Error::NotEnoughBalance(format!(
-                            "Not enough balance at 'source' for the operation: {}",
-                            amount
-                        ))
-                    }
-                    ClientError::NetworkDataError(SafeNdError::ExcessiveValue) => {
-                        Error::InvalidAmount(format!(
-                            "The amount '{}' specified for the transfer is invalid",
-                            amount
-                        ))
-                    }
-                    other => Error::NetDataError(format!("Failed to transfer coins: {:?}", other)),
-                })?;
-
-        // TODO: perhaps include the actor as part of the TX ID
-        Ok(dot_counter)
-    }
-
     // // === Blob operations ===
     pub async fn store_public_blob(&self, data: &[u8], dry_run: bool) -> Result<XorName> {
         let address = if dry_run {
@@ -248,10 +143,12 @@ impl SafeAppClient {
     }
 
     // === Map operations ===
+    #[allow(dead_code)]
     pub async fn store_map(
         &self,
         name: Option<XorName>,
         tag: u64,
+        kind: MapKind,
         _data: Option<String>,
         _permissions: Option<String>,
     ) -> Result<XorName> {
@@ -273,50 +170,49 @@ impl SafeAppClient {
         permission_map.insert(app_pk, permission_set);
 
         client
-            .store_seq_map(
+            .store_map(
                 xorname,
                 tag,
                 owner,
+                kind,
                 Some(BTreeMap::new()),
                 Some(permission_map),
             )
             .await
-            .map_err(|err| Error::NetDataError(format!("Failed to store SeqMap: {}", err)))?;
+            .map_err(|err| Error::NetDataError(format!("Failed to store Map: {}", err)))?;
 
         Ok(xorname)
     }
 
     #[allow(dead_code)]
-    pub async fn get_map(&self, name: XorName, tag: u64) -> Result<Map> {
+    pub async fn get_map(&self, address: MapAddress) -> Result<Map> {
         let client = self.get_safe_client()?;
-        let address = MapAddress::Seq { name, tag };
 
         client
             .get_map(address)
             .await
-            .map_err(|e| Error::NetDataError(format!("Failed to get SeqMap: {:?}", e)))
+            .map_err(|e| Error::NetDataError(format!("Failed to get Map: {:?}", e)))
     }
 
+    #[allow(dead_code)]
     pub async fn map_insert(
         &self,
-        name: XorName,
-        tag: u64,
-        key: &[u8],
-        value: &[u8],
+        address: MapAddress,
+        key: Vec<u8>,
+        pointer: XorName,
     ) -> Result<()> {
-        let entry_actions = MapSeqEntryActions::new();
-        let entry_actions = entry_actions.ins(key.to_vec(), value.to_vec(), 0);
-        self.edit_map_entries(name, tag, entry_actions, "Failed to insert to SeqMap")
+        let entry_actions = MapEntryActions::new();
+        let entry_actions = entry_actions.insert(key, pointer, 0);
+        self.edit_map_entries(address, entry_actions, "Failed to insert to Map")
             .await
     }
 
-    pub async fn map_get_value(&self, name: XorName, tag: u64, key: &[u8]) -> Result<MapValue> {
+    #[allow(dead_code)]
+    pub async fn map_get_value(&self, address: MapAddress, key: Vec<u8>) -> Result<MapValue> {
         let client = self.get_safe_client()?;
-        let key_vec = key.to_vec();
-        let address = MapAddress::Seq { name, tag };
 
         client
-            .get_map_value(address, key_vec)
+            .get_map_value(address, key)
             .await
             .map_err(|err| match err {
                 ClientError::ErrorMessage {
@@ -324,74 +220,55 @@ impl SafeAppClient {
                     ..
                 }
                 | ClientError::NetworkDataError(SafeNdError::AccessDenied(_)) => {
-                    Error::AccessDenied(format!("Failed to retrieve a key: {:?}", key))
+                    Error::AccessDenied("Failed to retrieve a key".to_string())
                 }
                 // FIXME: we need to match the appropriate error
                 // to map it to our Error::ContentNotFound
                 /*ClientError::NetworkDataError(??) => {
-                    Error::ContentNotFound(format!(
-                        "Sequenced Map not found at Xor name: {}",
-                        encode(&name)
-                    ))
+                    Error::ContentNotFound(format!("Map not found at address: {:?}", address))
                 }*/
-                ClientError::NetworkDataError(SafeNdError::NoSuchEntry) => {
-                    Error::EntryNotFound(format!(
-                        "Entry not found in Sequenced Map found at Xor name: {}",
-                        encode(&name)
-                    ))
-                }
+                ClientError::NetworkDataError(SafeNdError::NoSuchEntry) => Error::EntryNotFound(
+                    format!("Entry not found in Map found at address: {:?}", address),
+                ),
                 err => Error::NetDataError(format!("Failed to retrieve a key. {:?}", err)),
             })
     }
 
+    #[allow(dead_code)]
     pub async fn list_map_entries(
         &self,
-        name: XorName,
-        tag: u64,
-    ) -> Result<BTreeMap<Vec<u8>, MapSeqValue>> {
+        address: MapAddress,
+    ) -> Result<BTreeMap<Vec<u8>, MapValue>> {
         let client = self.get_safe_client()?;
         client
-            .list_seq_map_entries(name, tag)
+            .list_map_entries(address)
             .await
             .map_err(|err| match err {
                 ClientError::NetworkDataError(SafeNdError::AccessDenied(_pk)) => {
-                    Error::AccessDenied(format!(
-                        "Failed to get Sequenced Map at: {:?} (type tag: {})",
-                        name, tag
-                    ))
+                    Error::AccessDenied(format!("Failed to get Map at: {:?}", address))
                 }
                 // FIXME: we need to match the appropriate error
                 // to map it to our Error::ContentNotFound
                 /*ClientError::NetworkDataError(??) => {
-                    Error::ContentNotFound(format!(
-                        "Sequenced Map not found at Xor name: {} (type tag: {})",
-                        encode(&name),
-                        tag
-                    ))
+                    Error::ContentNotFound(format!("Map not found at address: {:?}", address))
                 }*/
-                ClientError::NetworkDataError(SafeNdError::NoSuchEntry) => {
-                    Error::EntryNotFound(format!(
-                        "Entry not found in Sequenced Map found at Xor name: {} (type tag: {})",
-                        encode(&name),
-                        tag
-                    ))
-                }
-                err => Error::NetDataError(format!("Failed to get Sequenced Map. {:?}", err)),
+                ClientError::NetworkDataError(SafeNdError::NoSuchEntry) => Error::EntryNotFound(
+                    format!("Entry not found in Map found at address: {:?}", address),
+                ),
+                err => Error::NetDataError(format!("Failed to get Map. {:?}", err)),
             })
     }
 
     async fn edit_map_entries(
         &self,
-        name: XorName,
-        tag: u64,
-        entry_actions: MapSeqEntryActions,
+        address: MapAddress,
+        entry_actions: MapEntryActions,
         error_msg: &str,
     ) -> Result<()> {
         let client = self.get_safe_client()?;
         let message = error_msg.to_string();
-        let address = MapAddress::Seq { name, tag };
         client
-            .edit_map_entries(address, MapEntryActions::Seq(entry_actions))
+            .edit_map_entries(address, entry_actions)
             .await
             .map_err(|err| {
                 if let ClientError::NetworkDataError(SafeNdError::InvalidEntryActions(_)) = err {
@@ -402,17 +279,17 @@ impl SafeAppClient {
             })
     }
 
+    #[allow(dead_code)]
     pub async fn update_map(
         &self,
-        name: XorName,
-        tag: u64,
-        key: &[u8],
-        value: &[u8],
+        address: MapAddress,
+        key: Vec<u8>,
+        pointer: XorName,
         version: u64,
     ) -> Result<()> {
-        let entry_actions = MapSeqEntryActions::new();
-        let entry_actions = entry_actions.update(key.to_vec(), value.to_vec(), version);
-        self.edit_map_entries(name, tag, entry_actions, "Failed to update SeqMD")
+        let entry_actions = MapEntryActions::new();
+        let entry_actions = entry_actions.update(key, pointer, version);
+        self.edit_map_entries(address, entry_actions, "Failed to update map")
             .await
     }
 
