@@ -17,7 +17,7 @@ use tracing_subscriber::{fmt, EnvFilter};
 // to be used for all sn_api tests
 const TEST_AUTH_CREDENTIALS: &str = "TEST_AUTH_CREDENTIALS";
 
-// Environment variable which can be set with the bootstraping contacts
+// Environment variable which can be set with the bootstrapping contacts
 // to be used for all sn_api tests
 const TEST_BOOTSTRAPPING_PEERS: &str = "TEST_BOOTSTRAPPING_PEERS";
 
@@ -58,14 +58,6 @@ pub async fn new_safe_instance() -> Result<Safe> {
     Ok(safe)
 }
 
-pub async fn new_read_only_safe_instance() -> Result<Safe> {
-    init_logger();
-    let mut safe = Safe::default();
-    let bootstrap_contacts = get_bootstrap_contacts()?;
-    safe.connect(None, None, Some(bootstrap_contacts)).await?;
-    Ok(safe)
-}
-
 // Create a random NRS name
 pub fn random_nrs_name() -> String {
     thread_rng().sample_iter(&Alphanumeric).take(15).collect()
